##############################################################################
#    Copyright (C) 2001, 2002, 2003 Lalo Martins <lalo@laranja.org>,
#                  Zope Corporation and Contributors

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA
"""An example of how to disable translations in a subtree
(and for that matter, an example of how to interact with Negotiator)
"""

from OFS.SimpleItem import SimpleItem
from OFS.PropertyManager import PropertyManager
from AccessControl import ClassSecurityInfo
from ZPublisher import BeforeTraverse
from Globals import InitializeClass

class StaticNegotiator(SimpleItem, PropertyManager):
    '''
    Store a static list of languages, and always negotiate to these,
    regardless of user and browser preference
    '''

    title = meta_type = 'Static language negotiator'
       
    manage_options = (PropertyManager.manage_options +
                      SimpleItem.manage_options)

    _properties=({'id':'languages', 'type': 'tokens', 'mode':'w'},
                 )
    languages = ('en',)
    property_extensible_schema__ = False

    def __init__(self, id):
        self._setId(id)

    def manage_beforeDelete(self, item, container):
        if item is self:
            handle = self.meta_type + '/' + self.getId()
            BeforeTraverse.unregisterBeforeTraverse(container, handle)

    def manage_afterAdd(self, item, container):
        if item is self:
            handle = self.meta_type + '/' + self.getId()
            container = container.this()
            nc = BeforeTraverse.NameCaller(self.getId())
            BeforeTraverse.registerBeforeTraverse(container, nc, handle)

    def __call__(self, container, req):
        '''
        The __before_publishing_traverse__ hook.
        '''
        req['pts_negotiator_accepted_languages'] = self.languages

InitializeClass(StaticNegotiator)


_req_marker = {}
def addFunction(dispatcher, REQUEST=_req_marker):
    """
    Create a new negotiator
    """
    id = REQUEST.get('id', 'static_language_negotiator')
    s=StaticNegotiator(id)
    dispatcher.Destination()._setObject(id, s)
    if REQUEST is not _req_marker:
        try: u = dispatcher.DestinationURL()
        except: u = REQUEST['URL1']
        REQUEST.RESPONSE.redirect(u+'/manage_main')
    return 'ok'
